@@ -1,7 +1,7 @@
 package Pcore::API::S3;
 
 use Pcore -class, -res, -const;
-use Pcore::Lib::Digest qw[sha256_hex hmac_sha256 hmac_sha256_hex];
+use Pcore::Lib::Digest qw[sha256_hex hmac_sha256_bin hmac_sha256_hex];
 use Pcore::Lib::Scalar qw[is_ref is_plain_coderef];
 use Pcore::Lib::Data qw[to_uri_query from_xml];
 use Pcore::Lib::Scalar qw[weaken];
@@ -128,10 +128,10 @@ sub _req1 ( $self, $args ) {
     my $credential_scope = "$date_ymd/$args->{region}/$self->{service}/aws4_request";
     my $string_to_sign   = "AWS4-HMAC-SHA256\n$date_iso08601\n$credential_scope\n" . sha256_hex $canon_req;
 
-    my $k_date    = hmac_sha256 $date_ymd, "AWS4$self->{secret}";
-    my $k_region  = hmac_sha256 $args->{region}, $k_date;
-    my $k_service = hmac_sha256 $self->{service}, $k_region;
-    my $sign_key  = hmac_sha256 'aws4_request', $k_service;
+    my $k_date    = hmac_sha256_bin $date_ymd, "AWS4$self->{secret}";
+    my $k_region  = hmac_sha256_bin $args->{region}, $k_date;
+    my $k_service = hmac_sha256_bin $self->{service}, $k_region;
+    my $sign_key  = hmac_sha256_bin 'aws4_request', $k_service;
     my $signature = hmac_sha256_hex $string_to_sign, $sign_key;
 
     # max retries number
