@@ -87,7 +87,7 @@ sub run ($self) {
     {
         print 'Setting tags ... ';
 
-        my $res = $self->{dist}->git->git_run( [ 'tag', $new_ver ] );
+        my $res = $self->{dist}->git->git_run(qq[tag -a "$new_ver" -m "Released version: $new_ver" ]);
         say $res && return if !$res;
 
         $res = $self->{dist}->git->git_run( [ 'tag', 'latest', '--force' ] );
@@ -97,16 +97,20 @@ sub run ($self) {
     }
 
     if ( $self->{dist}->git->upstream ) {
-      PUSH_UPSTREAM:
-        print 'Pushing to the upstream repository ... ';
-
-        my $res = $self->{dist}->git->git_run('push --follow-tags -f');
 
+        # pushing changesets
+      GIT_PUSH:
+        print 'Pushing changesets ... ';
+        my $res = $self->{dist}->git->git_run('push');
         say $res->{reason};
+        goto GIT_PUSH if !$res && P->term->prompt( q[Repeat?], [qw[yes no]], enter => 1 ) eq 'yes';
 
-        if ( !$res ) {
-            goto PUSH_UPSTREAM if P->term->prompt( q[Repeat?], [qw[yes no]], enter => 1 ) eq 'yes';
-        }
+        # pushing tags
+      GIT_PUSH_TAGS:
+        print 'Pushing tags ... ';
+        $res = $self->{dist}->git->git_run(qq[push origin -f "refs/tags/$new_ver" "refs/tags/latest"]);
+        say $res->{reason};
+        goto GIT_PUSH_TAGS if !$res && P->term->prompt( q[Repeat?], [qw[yes no]], enter => 1 ) eq 'yes';
     }
 
     # upload to the CPAN if this is the CPAN distribution, prompt before upload
@@ -311,6 +315,16 @@ TXT
 }
 
 1;
+## -----SOURCE FILTER LOG BEGIN-----
+##
+## PerlCritic profile "pcore-script" policy violations:
+## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
+## | Sev. | Lines                | Policy                                                                                                         |
+## |======+======================+================================================================================================================|
+## |    3 | 13                   | Subroutines::ProhibitExcessComplexity - Subroutine "run" with high complexity score (21)                       |
+## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
+##
+## -----SOURCE FILTER LOG END-----
 __END__
 =pod
 
